@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI
 from pydantic import BaseModel, EmailStr
 
@@ -8,7 +10,7 @@ class UserIn(BaseModel):
     username: str
     password: str
     email: EmailStr
-    full_name: str = None
+    full_name: Optional[str] = None
 
 
 # Don't do this in production!
